@@ -281,7 +281,7 @@ build_longer_spec <- function(data, cols,
   if (is.null(names_prefix)) {
     names <- names(cols)
   } else {
-    names <- stringi::stri_replace_all_regex(names(cols), paste0("^", names_prefix), "")
+    names <- gsub(paste0("^", names_prefix), "", names(cols))
   }
 
   if (length(names_to) > 1) {
